Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: third_party/WebKit/Source/core/dom/ExecutionContext.h

Issue 1373773003: Implement 'window.isSecureContext'. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: document. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Document.cpp ('k') | third_party/WebKit/Source/core/dom/Fullscreen.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/dom/ExecutionContext.h
diff --git a/third_party/WebKit/Source/core/dom/ExecutionContext.h b/third_party/WebKit/Source/core/dom/ExecutionContext.h
index 2221a6ef10274cfb58db5e94bcb577366948a805..c26e5c6b7a6daadf3944bc02e89d0b5866f7b1c9 100644
--- a/third_party/WebKit/Source/core/dom/ExecutionContext.h
+++ b/third_party/WebKit/Source/core/dom/ExecutionContext.h
@@ -63,12 +63,12 @@ class CORE_EXPORT ExecutionContext
public:
DECLARE_VIRTUAL_TRACE();
// Used to specify whether |isPrivilegedContext| should walk the
// ancestor tree to decide whether to restrict usage of a powerful
// feature.
- enum PrivilegeContextCheck {
- StandardPrivilegeCheck,
- WebCryptoPrivilegeCheck
+ enum SecureContextCheck {
+ StandardSecureContextCheck,
+ WebCryptoSecureContextCheck
};
virtual bool isDocument() const { return false; }
@@ -156,7 +156,7 @@ public:
// Decides whether this context is privileged, as described in
// https://w3c.github.io/webappsec/specs/powerfulfeatures/#settings-privileged.
- virtual bool isPrivilegedContext(String& errorMessage, const PrivilegeContextCheck = StandardPrivilegeCheck) const = 0;
+ virtual bool isSecureContext(String& errorMessage, const SecureContextCheck = StandardSecureContextCheck) const = 0;
virtual void setReferrerPolicy(ReferrerPolicy);
ReferrerPolicy referrerPolicy() const { return m_referrerPolicy; }
« no previous file with comments | « third_party/WebKit/Source/core/dom/Document.cpp ('k') | third_party/WebKit/Source/core/dom/Fullscreen.cpp » ('j') | no next file with comments »
@@ -63,12 +63,12 @@ class CORE_EXPORT ExecutionContext
public:
DECLARE_VIRTUAL_TRACE();
- // Used to specify whether |isPrivilegedContext| should walk the
+ // Used to specify whether |isSecureContext| should walk the
// ancestor tree to decide whether to restrict usage of a powerful
// feature.

Powered by Google App Engine
This is Rietveld 408576698